# Cloudwatch logs

This pypi package has moved to https://pypi.org/project/aws-cloudwatch-logs/.

The package and module names are new: `aws_cloudwatch_logs`.

```
pip install aws-cloudwatch-logs
```
